import { TextField, InputAdornment } from '@mui/material';
import InputWrapper from './InputWrapper';
import { NsInputFieldProps } from './types';
import { NsLabel } from '../label';
import InputFieldWrapper from './InputFieldWrapper';
import { getAdornmentProps } from './getAdornmentProps';

/**
 * we are using fieldState in place of error prop
 * @param props { placeholder, fieldState, iconStart, iconEnd, iconSide }
 * @returns Input Field
 */
const NsInputField = (props: NsInputFieldProps) => {
    const { fieldState, iconStart, iconEnd, iconSide, InputLabelProps, label, error, InputProps, ...rest } = props;
    /** EndIcon is created so that we can automatically add success and error icon based of fieldState,
     *  it will override iconEnd. Also to note, InputProps is given to override both iconStart, iconEnd and EndIcon */
    let EndIcon: any = getAdornmentProps(rest.disabled || false, fieldState);

    return (
        <InputFieldWrapper>
            {label ? (
                <NsLabel {...InputLabelProps} error>
                    {label}
                </NsLabel>
            ) : null}
            <InputWrapper fieldState={fieldState} data-testid="ns-input-field">
                <TextField
                    {...rest}
                    InputProps={{
                        startAdornment: iconStart ? (
                            <InputAdornment position="start">{iconStart}</InputAdornment>
                        ) : null,
                        endAdornment: iconEnd ? <InputAdornment position="end">{iconEnd}</InputAdornment> : null,
                        ...EndIcon,
                        ...InputProps,
                    }}
                />
                {iconSide}
            </InputWrapper>
        </InputFieldWrapper>
    );
};
export default NsInputField;
